@@ -7,12 +7,14 @@ from dkist_processing_test.tasks.noop import NoOpTask
 from dkist_processing_test.tasks.noop import NoOpTask2
 
 
-noop = Workflow(process_category="test", process_name="noop", workflow_package=__package__)
+noop = Workflow(
+    process_category="test", process_name="noop", workflow_package=__package__, tags=["test"]
+)
 noop.add_node(task=NoOpTask, upstreams=None)
 
 
 noop_flow = Workflow(
-    process_category="test", process_name="noop_flow", workflow_package=__package__
+    process_category="test", process_name="noop_flow", workflow_package=__package__, tags=["test"]
 )
 noop_flow.add_node(task=NoOpTask, upstreams=None)
 noop_flow.add_node(task=NoOpTask2, upstreams=NoOpTask)
